@@ -1,11 +1,13 @@
 import dataclasses
 import re
-from datetime import timedelta
-from typing import Callable, List, Mapping, Optional, TypeVar
+from datetime import datetime, timedelta, timezone
+from typing import Any, Callable, Dict, List, Mapping, Optional, Tuple, TypeVar
 
 import click
 from rich.console import JustifyMethod
 
+from neuro_sdk import JobDescription, JobStatus, JobTelemetry
+
 _T = TypeVar("_T")
 
 
@@ -69,7 +71,7 @@ class JobColumnInfo:
 # Note: please keep the help for format specs in sync with the following data
 # structures.
 
-COLUMNS = [
+PS_COLUMNS = [
     JobColumnInfo(
         "id", "ID", "left", width=len("job-28040560-2a21-428e-a7c0-44c809490b53")
     ),
@@ -90,22 +92,49 @@ COLUMNS = [
     JobColumnInfo("preset", "PRESET", "left"),
 ]
 
-COLUMNS_DEFAULT_IGNORE = {
+PS_COLUMNS_DEFAULT_IGNORE = {
     "tags",
     "life_span",
     "created",
     "started",
     "finished",
+    "cluster_name",
+    "description",
     "workdir",
     "preset",
 }
 
+PS_COLUMNS_DEFAULT = {
+    col.id for col in PS_COLUMNS if col.id not in PS_COLUMNS_DEFAULT_IGNORE
+}
 
-def get_default_columns() -> List[JobColumnInfo]:
-    return [col for col in COLUMNS if col.id not in COLUMNS_DEFAULT_IGNORE]
+TOP_COLUMNS = PS_COLUMNS + [
+    JobColumnInfo("cpu", "CPU", "right", width=15),
+    JobColumnInfo("memory", "MEMORY (MB)", "right", width=15),
+    JobColumnInfo("gpu", "GPU (%)", "right", width=15),
+    JobColumnInfo("gpu_memory", "GPU_MEMORY (MB)", "right", width=15),
+]
+
+TOP_COLUMNS_DEFAULT = {
+    "id",
+    "when",
+    "cpu",
+    "memory",
+    "gpu",
+    "gpu_memory",
+}
 
 
-COLUMNS_MAP = {column.id: column for column in COLUMNS}
+def get_default_ps_columns() -> List[JobColumnInfo]:
+    return [col for col in PS_COLUMNS if col.id in PS_COLUMNS_DEFAULT]
+
+
+def get_default_top_columns() -> List[JobColumnInfo]:
+    return [col for col in TOP_COLUMNS if col.id in TOP_COLUMNS_DEFAULT]
+
+
+PS_COLUMNS_MAP = {column.id: column for column in PS_COLUMNS}
+TOP_COLUMNS_MAP = {column.id: column for column in TOP_COLUMNS}
 
 COLUMNS_RE = re.compile(
     r"""
@@ -155,12 +184,22 @@ def _justify(arg: str) -> JustifyMethod:
     return arg  # type: ignore
 
 
-def parse_columns(fmt: Optional[str]) -> List[JobColumnInfo]:
+def parse_ps_columns(fmt: Optional[str]) -> List[JobColumnInfo]:
+    return _parse_columns(fmt, PS_COLUMNS_MAP) or get_default_ps_columns()
+
+
+def parse_top_columns(fmt: Optional[str]) -> List[JobColumnInfo]:
+    return _parse_columns(fmt, TOP_COLUMNS_MAP) or get_default_top_columns()
+
+
+def _parse_columns(
+    fmt: Optional[str], columns_map: Dict[str, JobColumnInfo]
+) -> Optional[List[JobColumnInfo]]:
     # Column format is "{id[;field=val][;title]}",
     # columns are separated by commas or spaces
     # spaces in title are forbidden
     if not fmt:
-        return get_default_columns()
+        return None
     ret = []
     for m1 in COLUMNS_RE.finditer(fmt):
         if m1.lastgroup == "sep":
@@ -178,19 +217,19 @@ def parse_columns(fmt: Optional[str]) -> List[JobColumnInfo]:
             raise ValueError(f"Invalid format {fmt!r}")
         groups = m2.groupdict()
         id = groups["id"].lower()
-        default = COLUMNS_MAP.get(id)
+        default = columns_map.get(id)
         if default is None:
-            for name in COLUMNS_MAP:
+            for name in columns_map:
                 if name.startswith(id):
                     if default is not None:
                         variants = ", ".join(
-                            name for name in COLUMNS_MAP if name.startswith(id)
+                            name for name in columns_map if name.startswith(id)
                         )
                         raise ValueError(
                             f"Ambiguous column {id!r} in format {fmt!r};"
                             f" available variants: {variants}"
                         )
-                    default = COLUMNS_MAP[name]
+                    default = columns_map[name]
             if default is None:
                 raise ValueError(f"Unknown column {id!r} in format {fmt!r}")
         title = _get(groups, "title", fmt, str, default.title)
@@ -216,6 +255,81 @@ def parse_columns(fmt: Optional[str]) -> List[JobColumnInfo]:
     return ret
 
 
+class InvertKey:
+    def __init__(self, value: Any) -> None:
+        self.value = Any
+
+    def __lt__(self, other: Any) -> Any:
+        return self.value > other.value
+
+    def __gt__(self, other: Any) -> Any:
+        return self.value < other.value
+
+    def __le__(self, other: Any) -> Any:
+        return self.value >= other.value
+
+    def __ge__(self, other: Any) -> Any:
+        return self.value <= other.value
+
+    def __eq__(self, other: Any) -> Any:
+        return self.value == other.value
+
+    def __ne__(self, other: Any) -> Any:
+        return self.value != other.value
+
+
+JobTelemetryKeyFunc = Callable[[Tuple[JobDescription, JobTelemetry]], Any]
+
+JOB_STATUS_PRIORITIES = {status: i for i, status in enumerate(JobStatus)}
+DATETIME_MIN = datetime.min.replace(tzinfo=timezone.utc)
+INF = float("inf")
+
+SORT_KEY_FUNCS: Dict[str, JobTelemetryKeyFunc] = {
+    # JobDescriptor attibutes
+    "id": lambda item: item[0].id,
+    "name": lambda item: item[0].name or "",
+    "status": lambda item: JOB_STATUS_PRIORITIES[item[0].status],
+    "created": lambda item: item[0].history.created_at or DATETIME_MIN,
+    "started": lambda item: item[0].history.started_at or DATETIME_MIN,
+    "finished": lambda item: item[0].history.finished_at or DATETIME_MIN,
+    "when": lambda item: item[0].history.changed_at,
+    "image": lambda item: str(item[0].container.image),
+    "owner": lambda item: item[0].owner,
+    "description": lambda item: item[0].description or "",
+    "cluster_name": lambda item: item[0].cluster_name,
+    "command": lambda item: item[0].container.command,
+    "life_span": lambda item: item[0].life_span or INF,
+    "workdir": lambda item: item[0].container.working_dir or "",
+    "preset": lambda item: item[0].preset_name or "",
+    # JobTelemetry attibutes
+    "cpu": lambda item: -item[1].cpu,
+    "memory": lambda item: -item[1].memory,
+    "gpu": lambda item: -(item[1].gpu_duty_cycle or 0),
+    "gpu_memory": lambda item: -(item[1].gpu_memory or 0),
+}
+
+SORT_KEY_NAMES = tuple(SORT_KEY_FUNCS)
+
+
+def parse_sort_keys(fmt: str) -> List[Tuple[JobTelemetryKeyFunc, bool]]:
+    sort_keys: List[Tuple[JobTelemetryKeyFunc, bool]] = []
+    for keyname in fmt.split(","):
+        keyname = keyname.strip()
+        if keyname[:1] == "-":
+            reverse = True
+            keyname = keyname[1:]
+        else:
+            reverse = False
+
+        try:
+            keyfunc = SORT_KEY_FUNCS[keyname]
+        except KeyError:
+            raise ValueError(f"invalid sort key {keyname!r}") from None
+        sort_keys.append((keyfunc, reverse))
+
+    return sort_keys
+
+
 REGEX_TIME_DELTA = re.compile(
     r"^((?P<d>\d+)d)?((?P<h>\d+)h)?((?P<m>\d+)m)?((?P<s>\d+)s)?$"
 )
